starcluster.commands.showimage

Package starcluster :: Package commands :: Module showimage |
[hide private]
[frames] | no frames]

# Source Code for Module starcluster.commands.showimage

     1  #!/usr/bin/env python
     2
     3  from completers import S3ImageCompleter
     4
     5
     6 -class CmdShowImage(S3ImageCompleter):
     7      """
     8      showimage <image_id>
     9
    10      Show all AMI parts and manifest files on S3 for an instance-store AMI
    11
    12      Example:
    13
    14          $ starcluster showimage ami-999999
    15      """
    16      names = ['showimage', 'shimg']
    17
    18 -    def execute(self, args):
    19          if not args:
    20              self.parser.error('please specify an AMI id')
    21          for arg in args:
    22              self.ec2.list_image_files(arg)
    23